[vlc-devel] [PATCH] Correct widespread misuse of the word 'subtitle'

Edward Wang edward.c.wang at compdigitec.com
Wed Mar 13 19:21:14 CET 2013


Subtitle is the adjective describing what kind of text. So "subtitle text" is an adjective phrase describing what kind of encoding.

For example, we don't listen to "audios tracks", program "videos codecs", or open "playlists files". Therefore, use the correct form of the word subtitle for the context.
---
 extras/package/macosx/README.MacOSX.rtf            |    4 ++--
 .../macosx/Resources/English.lproj/MainMenu.xib    |    4 ++--
 .../macosx/Resources/English.lproj/Open.xib        |    4 ++--
 .../macosx/Resources/English.lproj/SyncTracks.xib  |    4 ++--
 include/vlc_config_cat.h                           |    8 ++++----
 modules/codec/subsdec.c                            |   12 ++++++------
 modules/control/rc.c                               |    2 +-
 modules/demux/ogg.c                                |    2 +-
 modules/demux/subtitle.c                           |    8 ++++----
 modules/gui/macosx/MainMenu.m                      |   10 +++++-----
 modules/gui/macosx/TrackSynchronization.m          |   10 +++++-----
 modules/gui/macosx/open.m                          |    6 +++---
 modules/gui/macosx/simple_prefs.m                  |    2 +-
 modules/gui/qt4/components/controller.hpp          |    2 +-
 modules/gui/qt4/components/extended_panels.cpp     |   10 +++++-----
 modules/gui/qt4/components/open_panels.cpp         |    2 +-
 modules/gui/qt4/components/simple_preferences.cpp  |    4 ++--
 modules/gui/qt4/dialogs_provider.hpp               |    2 +-
 modules/gui/qt4/menus.cpp                          |    2 +-
 modules/gui/qt4/ui/open_disk.ui                    |    2 +-
 modules/gui/qt4/ui/open_file.ui                    |    6 +++---
 modules/gui/qt4/ui/sprefs_subtitles.ui             |    6 +++---
 modules/stream_out/transcode/spu.c                 |    8 ++++----
 modules/stream_out/transcode/transcode.c           |    8 ++++----
 modules/video_filter/subsdelay.c                   |    4 ++--
 modules/video_output/msw/direct3d.c                |    2 +-
 share/lua/http/dialogs/old/input                   |    6 +++---
 share/lua/http/dialogs/old/sout                    |    4 ++--
 share/lua/intf/cli.lua                             |    2 +-
 src/input/input.c                                  |    4 ++--
 src/input/var.c                                    |    2 +-
 src/libvlc-module.c                                |    6 +++---
 32 files changed, 79 insertions(+), 79 deletions(-)

diff --git a/extras/package/macosx/README.MacOSX.rtf b/extras/package/macosx/README.MacOSX.rtf
index 8493256..c593153 100644
--- a/extras/package/macosx/README.MacOSX.rtf
+++ b/extras/package/macosx/README.MacOSX.rtf
@@ -113,7 +113,7 @@ Simply drag VLC from the place where you had installed it, to the Trash. If you
 \pard\tx1440\tx2880\tx4320\tx5760\tx7200\qj
 
 \b0 \cf0 \ulnone - VLC will autodetect subtitle files when they are in the same directory as your movie and contain the movie's filename.\
-- DVD and autodetected subtitles  can be enabled trough the Video -> Subtitles Track menu-item.\
+- DVD and autodetected subtitles can be enabled trough the Video -> Subtitle Track menu-item.\
 - Only Vobsub, MicroDVD, SubRIP, SSA1-4. SAMI and vplayer subtitle files are supported at the moment.\
 - You cannot change anything about DVD and Vobsub subtitles.\
 - You can add any subtitle files to a video file via the Open.. dialog.\
@@ -165,4 +165,4 @@ An editable wiki is available at \ul http://wiki.videolan.org\ulnone .\
 For additional information and support, please see: \ul http://www.videolan.org/support\ulnone \
 -- \
 Derk-Jan Hartman & Felix Paul K\'fchne for the VideoLAN team.\
-}
\ No newline at end of file
+}
diff --git a/extras/package/macosx/Resources/English.lproj/MainMenu.xib b/extras/package/macosx/Resources/English.lproj/MainMenu.xib
index 8172d60..ee0e3e5 100644
--- a/extras/package/macosx/Resources/English.lproj/MainMenu.xib
+++ b/extras/package/macosx/Resources/English.lproj/MainMenu.xib
@@ -2246,7 +2246,7 @@
                 </object>
                 <object class="NSMenuItem" id="897405414">
                   <reference key="NSMenu" ref="598695780"/>
-                  <string key="NSTitle">Subtitles track</string>
+                  <string key="NSTitle">Subtitle track</string>
                   <string key="NSKeyEquiv"/>
                   <int key="NSKeyEquivModMask">1048576</int>
                   <int key="NSMnemonicLoc">2147483647</int>
@@ -2254,7 +2254,7 @@
                   <reference key="NSMixedImage" ref="100133332"/>
                   <string key="NSAction">submenuAction:</string>
                   <object class="NSMenu" key="NSSubmenu" id="451511994">
-                    <string key="NSTitle">Subtitles track</string>
+                    <string key="NSTitle">Subtitle track</string>
                     <object class="NSMutableArray" key="NSMenuItems">
                       <bool key="EncodedWithXMLCoder">YES</bool>
                       <object class="NSMenuItem" id="582837384">
diff --git a/extras/package/macosx/Resources/English.lproj/Open.xib b/extras/package/macosx/Resources/English.lproj/Open.xib
index 459df67..6738bab 100644
--- a/extras/package/macosx/Resources/English.lproj/Open.xib
+++ b/extras/package/macosx/Resources/English.lproj/Open.xib
@@ -214,7 +214,7 @@
                         <object class="NSButtonCell" key="NSCell" id="505386145">
                           <int key="NSCellFlags">67239424</int>
                           <int key="NSCellFlags2">0</int>
-                          <string key="NSContents">Load subtitles file:</string>
+                          <string key="NSContents">Load subtitle file:</string>
                           <reference key="NSSupport" ref="725567486"/>
                           <reference key="NSControlView" ref="895203276"/>
                           <int key="NSButtonFlags">1211912703</int>
@@ -1339,7 +1339,7 @@ c3ViX2FsaWduX2xibDsKCg</string>
                       <object class="NSTextFieldCell" key="NSCell" id="16061800">
                         <int key="NSCellFlags">67239424</int>
                         <int key="NSCellFlags2">4194304</int>
-                        <string key="NSContents">Subtitles justification</string>
+                        <string key="NSContents">Subtitle justification</string>
                         <reference key="NSSupport" ref="725567486"/>
                         <reference key="NSControlView" ref="1062804181"/>
                         <reference key="NSBackgroundColor" ref="227735768"/>
diff --git a/extras/package/macosx/Resources/English.lproj/SyncTracks.xib b/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
index e48b0f0..6c96fbe 100644
--- a/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
+++ b/extras/package/macosx/Resources/English.lproj/SyncTracks.xib
@@ -390,7 +390,7 @@
                       <object class="NSTextFieldCell" key="NSCell" id="432856306">
                         <int key="NSCellFlags">68288064</int>
                         <int key="NSCellFlags2">272761856</int>
-                        <string key="NSContents">Subtitles speed:</string>
+                        <string key="NSContents">Subtitle speed:</string>
                         <reference key="NSSupport" ref="26"/>
                         <reference key="NSControlView" ref="1031205444"/>
                         <reference key="NSBackgroundColor" ref="592262308"/>
@@ -485,7 +485,7 @@
                       <object class="NSTextFieldCell" key="NSCell" id="888222676">
                         <int key="NSCellFlags">68288064</int>
                         <int key="NSCellFlags2">272761856</int>
-                        <string key="NSContents">Subtitles duration factor:</string>
+                        <string key="NSContents">Subtitle duration factor:</string>
                         <reference key="NSSupport" ref="26"/>
                         <reference key="NSControlView" ref="934030007"/>
                         <reference key="NSBackgroundColor" ref="592262308"/>
diff --git a/include/vlc_config_cat.h b/include/vlc_config_cat.h
index 5488f17..d4cdaf8 100644
--- a/include/vlc_config_cat.h
+++ b/include/vlc_config_cat.h
@@ -115,8 +115,8 @@
 #define ADEC_TITLE  N_( "Audio codecs" )
 #define ADEC_HELP N_( "Settings for the audio-only decoders and encoders." )
 
-#define SDEC_TITLE N_( "Subtitles codecs")
-#define SDEC_HELP N_( "Settings for subtitles, teletext and CC decoders and encoders." )
+#define SDEC_TITLE N_( "Subtitle codecs")
+#define SDEC_HELP N_( "Settings for subtitle, teletext and CC decoders and encoders." )
 
 #define ADVANCED_TITLE N_("General Input" )
 #define ADVANCED_HELP N_( "General input settings. Use with care..." )
@@ -200,7 +200,7 @@
 
 #define ENCODER_TITLE N_("Encoders settings")
 #define ENCODER_HELP N_( \
-    "These are general settings for video/audio/subtitles encoding modules.")
+    "These are general settings for video/audio/subtitle encoding modules.")
 
 
 #define DIALOGS_TITLE N_("Dialog providers settings")
@@ -210,7 +210,7 @@
 #define SUBTITLE_DEMUX_TITLE N_("Subtitle demuxer settings")
 #define SUBTITLE_DEMUX_HELP N_( \
     "In this section you can force the behavior of the subtitle demuxer, " \
-    "for example by setting the subtitles type or file name.")
+    "for example by setting the subtitle type or file name.")
 
 /*
  *  A little help for modules with unknown capabilities
diff --git a/modules/control/rc.c b/modules/control/rc.c
index fa45523..39b9af5 100644
--- a/modules/control/rc.c
+++ b/modules/control/rc.c
@@ -853,7 +853,7 @@ static void Help( intf_thread_t *p_intf, bool b_longhelp)
     msg_rc("%s", _("| vcrop [X]  . . . . . . . . . . .  set/get video crop"));
     msg_rc("%s", _("| vzoom [X]  . . . . . . . . . . .  set/get video zoom"));
     msg_rc("%s", _("| snapshot . . . . . . . . . . . . take video snapshot"));
-    msg_rc("%s", _("| strack [X] . . . . . . . . . set/get subtitles track"));
+    msg_rc("%s", _("| strack [X] . . . . . . . . .  set/get subtitle track"));
     msg_rc("%s", _("| key [hotkey name] . . . . . .  simulate hotkey press"));
     msg_rc("%s", _("| menu . . [on|off|up|down|left|right|select] use menu"));
     msg_rc(  "| ");
diff --git a/modules/demux/ogg.c b/modules/demux/ogg.c
index 114d8ef..1850771 100644
--- a/modules/demux/ogg.c
+++ b/modules/demux/ogg.c
@@ -1487,7 +1487,7 @@ static int Ogg_FindLogicalStreams( demux_t *p_demux )
                         /* We need to get rid of the header packet */
                         ogg_stream_packetout( &p_stream->os, &oggpacket );
 
-                        msg_Dbg( p_demux, "found text subtitles header" );
+                        msg_Dbg( p_demux, "found text subtitle header" );
                         p_stream->fmt.i_cat = SPU_ES;
                         p_stream->fmt.i_codec = VLC_CODEC_SUBT;
                         p_stream->f_rate = 1000; /* granulepos is in millisec */
diff --git a/modules/demux/subtitle.c b/modules/demux/subtitle.c
index aa1c7e6..a1dc7bd 100644
--- a/modules/demux/subtitle.c
+++ b/modules/demux/subtitle.c
@@ -67,7 +67,7 @@ static const char *const ppsz_sub_type[] =
 
 vlc_module_begin ()
     set_shortname( N_("Subtitles"))
-    set_description( N_("Text subtitles parser") )
+    set_description( N_("Text subtitle parser") )
     set_capability( "demux", 0 )
     set_category( CAT_INPUT )
     set_subcategory( SUBCAT_INPUT_DEMUX )
@@ -75,12 +75,12 @@ vlc_module_begin ()
                N_("Frames per second"),
                SUB_FPS_LONGTEXT, true )
     add_integer( "sub-delay", 0,
-               N_("Subtitles delay"),
+               N_("Subtitle delay"),
                SUB_DELAY_LONGTEXT, true )
-    add_string( "sub-type", "auto", N_("Subtitles format"),
+    add_string( "sub-type", "auto", N_("Subtitle format"),
                 SUB_TYPE_LONGTEXT, true )
         change_string_list( ppsz_sub_type, ppsz_sub_type )
-    add_string( "sub-description", NULL, N_("Subtitles description"),
+    add_string( "sub-description", NULL, N_("Subtitle description"),
                 SUB_DESCRIPTION_LONGTEXT, true )
     set_callbacks( Open, Close )
 
diff --git a/modules/gui/macosx/MainMenu.m b/modules/gui/macosx/MainMenu.m
index a016c61..0cc28b4 100644
--- a/modules/gui/macosx/MainMenu.m
+++ b/modules/gui/macosx/MainMenu.m
@@ -391,8 +391,8 @@ static VLCMainMenu *_o_sharedInstance = nil;
     [o_mu_crop setTitle: _NS("Crop")];
     [o_mi_screen setTitle: _NS("Fullscreen Video Device")];
     [o_mu_screen setTitle: _NS("Fullscreen Video Device")];
-    [o_mi_subtitle setTitle: _NS("Subtitles Track")];
-    [o_mu_subtitle setTitle: _NS("Subtitles Track")];
+    [o_mi_subtitle setTitle: _NS("Subtitle Track")];
+    [o_mu_subtitle setTitle: _NS("Subtitle Track")];
     [o_mi_addSub setTitle: _NS("Open File...")];
     [o_mi_deinterlace setTitle: _NS("Deinterlace")];
     [o_mu_deinterlace setTitle: _NS("Deinterlace")];
@@ -1174,7 +1174,7 @@ static VLCMainMenu *_o_sharedInstance = nil;
     }
 
     /* special case for the subtitles item */
-    if ([[o_parent title] isEqualToString: _NS("Subtitles Track")] == YES) {
+    if ([[o_parent title] isEqualToString: _NS("Subtitle Track")] == YES) {
         NSMenuItem * o_lmi_tmp;
         o_lmi_tmp = [o_menu addItemWithTitle: _NS("Open File...") action: @selector(addSubtitleFile:) keyEquivalent: @""];
         [o_lmi_tmp setTarget: [[VLCMain sharedInstance] controls]];
@@ -1222,7 +1222,7 @@ static VLCMainMenu *_o_sharedInstance = nil;
     [o_parent setEnabled: (val_list.p_list->i_count > 1)];
 
     /* another special case for the subtitles item */
-    if ([[o_parent title] isEqualToString: _NS("Subtitles Track")] == YES)
+    if ([[o_parent title] isEqualToString: _NS("Subtitle Track")] == YES)
         [o_menu addItem: [NSMenuItem separatorItem]];
 
     for (i = 0; i < val_list.p_list->i_count; i++) {
@@ -1268,7 +1268,7 @@ static VLCMainMenu *_o_sharedInstance = nil;
 
     /* special case for the subtitles sub-menu
      * In case that we don't have any subs, we don't want a separator item at the end */
-    if ([[o_parent title] isEqualToString: _NS("Subtitles Track")] == YES) {
+    if ([[o_parent title] isEqualToString: _NS("Subtitle Track")] == YES) {
         if ([o_menu numberOfItems] == 2)
             [o_menu removeItemAtIndex: 1];
     }
diff --git a/modules/gui/macosx/TrackSynchronization.m b/modules/gui/macosx/TrackSynchronization.m
index 61e6138..1206dba 100644
--- a/modules/gui/macosx/TrackSynchronization.m
+++ b/modules/gui/macosx/TrackSynchronization.m
@@ -66,9 +66,9 @@ static VLCTrackSynchronization *_o_sharedInstance = nil;
     [o_sv_advance_lbl setStringValue: _NS("Subtitle track syncronization:")];
     [[o_sv_advance_value_fld formatter] setFormat:[NSString stringWithFormat:@"#,##0.000 %@", _NS("s")]];
     [o_sv_advance_value_fld setToolTip: _NS("A positive value means that the subtitles are ahead of the video")];
-    [o_sv_speed_lbl setStringValue: _NS("Subtitles speed:")];
+    [o_sv_speed_lbl setStringValue: _NS("Subtitle speed:")];
     [[o_sv_speed_value_fld formatter] setFormat:[NSString stringWithFormat:@"#,##0.000 %@", _NS("fps")]];
-    [o_sv_dur_lbl setStringValue: _NS("Subtitles duration factor:")];
+    [o_sv_dur_lbl setStringValue: _NS("Subtitle duration factor:")];
 
     int i_mode = var_InheritInteger(p_intf, SUBSDELAY_CFG_MODE);
     NSString * o_toolTip, * o_suffix;
@@ -76,15 +76,15 @@ static VLCTrackSynchronization *_o_sharedInstance = nil;
     switch (i_mode) {
         default:
         case SUBSDELAY_MODE_ABSOLUTE:
-            o_toolTip = _NS("Extend subtitles duration by this value.\nSet 0 to disable.");
+            o_toolTip = _NS("Extend subtitle duration by this value.\nSet 0 to disable.");
             o_suffix = @" s";
             break;
         case SUBSDELAY_MODE_RELATIVE_SOURCE_DELAY:
-            o_toolTip = _NS("Multiply subtitles duration by this value.\nSet 0 to disable.");
+            o_toolTip = _NS("Multiply subtitle duration by this value.\nSet 0 to disable.");
             o_suffix = @"";
             break;
         case SUBSDELAY_MODE_RELATIVE_SOURCE_CONTENT:
-            o_toolTip = _NS("Recalculate subtitles duration according\nto their content and this value.\nSet 0 to disable.");
+            o_toolTip = _NS("Recalculate subtitle duration according\nto their content and this value.\nSet 0 to disable.");
             o_suffix = @"";
             break;
     }
diff --git a/modules/gui/macosx/open.m b/modules/gui/macosx/open.m
index e64d517..d015c49 100644
--- a/modules/gui/macosx/open.m
+++ b/modules/gui/macosx/open.m
@@ -348,7 +348,7 @@ static VLCOpen *_o_sharedMainInstance = nil;
     module_config_t * p_item;
     intf_thread_t * p_intf = VLCIntf;
 
-    [o_file_sub_ckbox setTitle: _NS("Load subtitles file:")];
+    [o_file_sub_ckbox setTitle: _NS("Load subtitle file:")];
     [o_file_sub_path_lbl setStringValue: _NS("Choose a file")];
     [o_file_sub_path_lbl setHidden: NO];
     [o_file_sub_path_fld setStringValue: @""];
@@ -361,11 +361,11 @@ static VLCOpen *_o_sharedMainInstance = nil;
     [o_file_sub_delay_stp setEnabled: NO];
     [o_file_sub_fps_lbl setStringValue: _NS("FPS")];
     [o_file_sub_fps_stp setEnabled: NO];
-    [o_file_sub_encoding_lbl setStringValue: _NS("Subtitles encoding")];
+    [o_file_sub_encoding_lbl setStringValue: _NS("Subtitle encoding")];
     [o_file_sub_encoding_pop removeAllItems];
     [o_file_sub_size_lbl setStringValue: _NS("Font size")];
     [o_file_sub_size_pop removeAllItems];
-    [o_file_sub_align_lbl setStringValue: _NS("Subtitles alignment")];
+    [o_file_sub_align_lbl setStringValue: _NS("Subtitle alignment")];
     [o_file_sub_align_pop removeAllItems];
     [o_file_sub_ok_btn setStringValue: _NS("OK")];
     [[o_file_sub_ok_btn cell] accessibilitySetOverrideValue:_NS("Click to dismiss the subtitle setup dialog.") forAttribute:NSAccessibilityDescriptionAttribute];
diff --git a/modules/gui/macosx/simple_prefs.m b/modules/gui/macosx/simple_prefs.m
index 9d76127..a91fe3a 100644
--- a/modules/gui/macosx/simple_prefs.m
+++ b/modules/gui/macosx/simple_prefs.m
@@ -143,7 +143,7 @@ create_toolbar_item(NSString * o_itemIdent, NSString * o_name, NSString * o_desc
     } else if ([o_itemIdent isEqual: VLCVideoSettingToolbarIdentifier]) {
         CreateToolbarItem(_NS("Video"), _NS("General Video Settings"), @"spref_cone_Video_64", showVideoSettings);
     } else if ([o_itemIdent isEqual: VLCOSDSettingToolbarIdentifier]) {
-        CreateToolbarItem(_NS(SUBPIC_TITLE), _NS("Subtitles & On Screen Display Settings"), @"spref_cone_Subtitles_64", showOSDSettings);
+        CreateToolbarItem(_NS(SUBPIC_TITLE), _NS("Subtitle & On Screen Display Settings"), @"spref_cone_Subtitles_64", showOSDSettings);
     } else if ([o_itemIdent isEqual: VLCInputSettingToolbarIdentifier]) {
         CreateToolbarItem(_NS(INPUT_TITLE), _NS("Input & Codec settings"), @"spref_cone_Input_64", showInputSettings);
     } else if ([o_itemIdent isEqual: VLCHotkeysSettingToolbarIdentifier]) {
diff --git a/modules/gui/qt4/components/controller.hpp b/modules/gui/qt4/components/controller.hpp
index 0f7ab00..b4f839e 100644
--- a/modules/gui/qt4/components/controller.hpp
+++ b/modules/gui/qt4/components/controller.hpp
@@ -131,7 +131,7 @@ static const char* const tooltipL[BUTTON_MAX] = { I_PLAY_TOOLTIP,
     N_("Reverse"), N_("Step backward"), N_("Step forward"), N_("Quit"),
     N_("Random"), N_("Change the loop and repeat modes"), N_("Information"),
     N_("Previous media in the playlist"), N_("Next media in the playlist"),
-    N_("Open subtitles file"),
+    N_("Open subtitle file"),
     N_("Dock/undock fullscreen controller to/from bottom of screen")
 };
 static const QString iconL[BUTTON_MAX] ={ ":/toolbar/play_b", ":/toolbar/stop_b",
diff --git a/modules/gui/qt4/components/extended_panels.cpp b/modules/gui/qt4/components/extended_panels.cpp
index ed6c275..01dc484 100644
--- a/modules/gui/qt4/components/extended_panels.cpp
+++ b/modules/gui/qt4/components/extended_panels.cpp
@@ -1489,7 +1489,7 @@ SyncControls::SyncControls( intf_thread_t *_p_intf, QWidget *_parent ) :
     subsLayout->addWidget( subsSpin, 0, 2, 1, 1 );
 
     QLabel *subSpeedLabel = new QLabel;
-    subSpeedLabel->setText( qtr( "Subtitles speed:" ) );
+    subSpeedLabel->setText( qtr( "Subtitle speed:" ) );
     subsLayout->addWidget( subSpeedLabel, 1, 0, 1, 1 );
 
     subSpeedSpin = new QDoubleSpinBox;
@@ -1503,7 +1503,7 @@ SyncControls::SyncControls( intf_thread_t *_p_intf, QWidget *_parent ) :
     subsLayout->addWidget( subSpeedSpin, 1, 2, 1, 1 );
 
     QLabel *subDurationLabel = new QLabel;
-    subDurationLabel->setText( qtr( "Subtitles duration factor:" ) );
+    subDurationLabel->setText( qtr( "Subtitle duration factor:" ) );
     subsLayout->addWidget( subDurationLabel, 2, 0, 1, 1 );
 
     subDurationSpin = new QDoubleSpinBox;
@@ -1614,17 +1614,17 @@ void SyncControls::initSubsDuration()
     {
     default:
     case SUBSDELAY_MODE_ABSOLUTE:
-        subDurationSpin->setToolTip( qtr( "Extend subtitles duration by this value.\n"
+        subDurationSpin->setToolTip( qtr( "Extend subtitle duration by this value.\n"
                                           "Set 0 to disable." ) );
         subDurationSpin->setSuffix( " s" );
         break;
     case SUBSDELAY_MODE_RELATIVE_SOURCE_DELAY:
-        subDurationSpin->setToolTip( qtr( "Multiply subtitles duration by this value.\n"
+        subDurationSpin->setToolTip( qtr( "Multiply subtitle duration by this value.\n"
                                           "Set 0 to disable." ) );
         subDurationSpin->setSuffix( "" );
         break;
     case SUBSDELAY_MODE_RELATIVE_SOURCE_CONTENT:
-        subDurationSpin->setToolTip( qtr( "Recalculate subtitles duration according\n"
+        subDurationSpin->setToolTip( qtr( "Recalculate subtitle duration according\n"
                                           "to their content and this value.\n"
                                           "Set 0 to disable." ) );
         subDurationSpin->setSuffix( "" );
diff --git a/modules/gui/qt4/components/open_panels.cpp b/modules/gui/qt4/components/open_panels.cpp
index 9248085..0d57d02 100644
--- a/modules/gui/qt4/components/open_panels.cpp
+++ b/modules/gui/qt4/components/open_panels.cpp
@@ -249,7 +249,7 @@ void FileOpenPanel::removeFile()
 void FileOpenPanel::browseFileSub()
 {
     // TODO Handle selection of more than one subtitles file
-    QStringList files = THEDP->showSimpleOpen( qtr("Open subtitles file"),
+    QStringList files = THEDP->showSimpleOpen( qtr("Open subtitle file"),
                            EXT_FILTER_SUBTITLE, p_intf->p_sys->filepath );
 
     if( files.isEmpty() ) return;
diff --git a/modules/gui/qt4/components/simple_preferences.cpp b/modules/gui/qt4/components/simple_preferences.cpp
index dc0a8af..fd9fc60 100644
--- a/modules/gui/qt4/components/simple_preferences.cpp
+++ b/modules/gui/qt4/components/simple_preferences.cpp
@@ -88,7 +88,7 @@ SPrefsCatList::SPrefsCatList( intf_thread_t *_p_intf, QWidget *_parent, bool sma
                   cone_audio_64, 1 );
     ADD_CATEGORY( SPrefsVideo, qtr("Video"), qtr("Video Settings"),
                   cone_video_64, 2 );
-    ADD_CATEGORY( SPrefsSubtitles, SUBPIC_TITLE, qtr("Subtitles & On Screen Display Settings"),
+    ADD_CATEGORY( SPrefsSubtitles, SUBPIC_TITLE, qtr("Subtitle & On Screen Display Settings"),
                   cone_subtitles_64, 3 );
     ADD_CATEGORY( SPrefsInputAndCodecs, INPUT_TITLE, qtr("Input & Codecs Settings"),
                   cone_input_64, 4 );
@@ -636,7 +636,7 @@ SPrefsPanel::SPrefsPanel( intf_thread_t *_p_intf, QWidget *_parent,
         END_SPREFS_CAT;
 
         START_SPREFS_CAT( Subtitles,
-                            qtr("Subtitles & On Screen Display Settings") );
+                            qtr("Subtitle & On Screen Display Settings") );
             CONFIG_BOOL( "osd", OSDBox);
             CONFIG_BOOL( "video-title-show", OSDTitleBox);
             CONFIG_GENERIC( "video-title-position", IntegerList,
diff --git a/modules/gui/qt4/dialogs_provider.hpp b/modules/gui/qt4/dialogs_provider.hpp
index 1e9282f..bc967b0 100644
--- a/modules/gui/qt4/dialogs_provider.hpp
+++ b/modules/gui/qt4/dialogs_provider.hpp
@@ -41,7 +41,7 @@
 #define TITLE_EXTENSIONS_VIDEO qtr( "Video Files" )
 #define TITLE_EXTENSIONS_AUDIO qtr( "Audio Files" )
 #define TITLE_EXTENSIONS_PLAYLIST qtr( "Playlist Files" )
-#define TITLE_EXTENSIONS_SUBTITLE qtr( "Subtitles Files" )
+#define TITLE_EXTENSIONS_SUBTITLE qtr( "Subtitle Files" )
 #define TITLE_EXTENSIONS_ALL qtr( "All Files" )
 #define EXTENSIONS_ALL "*"
 #define ADD_EXT_FILTER( string, type ) \
diff --git a/modules/gui/qt4/menus.cpp b/modules/gui/qt4/menus.cpp
index 167af3d..a9ff53f 100644
--- a/modules/gui/qt4/menus.cpp
+++ b/modules/gui/qt4/menus.cpp
@@ -621,7 +621,7 @@ QMenu *VLCMenuBar::AudioMenu( intf_thread_t *p_intf, QMenu * current )
 QMenu *VLCMenuBar::SubtitleMenu( QMenu *current )
 {
     QAction *action;
-    QMenu *submenu = new QMenu( qtr( "&Subtitles Track" ), current );
+    QMenu *submenu = new QMenu( qtr( "&Subtitle Track" ), current );
     action = current->addMenu( submenu );
     action->setData( "spu-es" );
     addDPStaticEntry( submenu, qtr( "Open File..." ), "",
diff --git a/modules/gui/qt4/ui/open_disk.ui b/modules/gui/qt4/ui/open_disk.ui
index 6512cb5..171002b 100644
--- a/modules/gui/qt4/ui/open_disk.ui
+++ b/modules/gui/qt4/ui/open_disk.ui
@@ -323,7 +323,7 @@
       <item row="0" column="3">
        <widget class="QLabel" name="subtitlesLabel">
         <property name="text">
-         <string>Subtitles track</string>
+         <string>Subtitle track</string>
         </property>
         <property name="buddy">
          <cstring>subtitlesSpin</cstring>
diff --git a/modules/gui/qt4/ui/open_file.ui b/modules/gui/qt4/ui/open_file.ui
index b1413ff..df7147d 100644
--- a/modules/gui/qt4/ui/open_file.ui
+++ b/modules/gui/qt4/ui/open_file.ui
@@ -102,10 +102,10 @@
       <bool>false</bool>
      </property>
      <property name="toolTip">
-      <string>Add a subtitles file</string>
+      <string>Add a subtitle file</string>
      </property>
      <property name="text">
-      <string>Use a sub&titles file</string>
+      <string>Use a sub&title file</string>
      </property>
     </widget>
    </item>
@@ -136,7 +136,7 @@
             </size>
            </property>
            <property name="toolTip">
-            <string>Select the subtitles file</string>
+            <string>Select the subtitle file</string>
            </property>
            <property name="text">
             <string>Browse...</string>
diff --git a/modules/gui/qt4/ui/sprefs_subtitles.ui b/modules/gui/qt4/ui/sprefs_subtitles.ui
index f49ce5c..e3db352 100644
--- a/modules/gui/qt4/ui/sprefs_subtitles.ui
+++ b/modules/gui/qt4/ui/sprefs_subtitles.ui
@@ -82,7 +82,7 @@
          </sizepolicy>
         </property>
         <property name="title">
-         <string>Subtitles Language</string>
+         <string>Subtitle Language</string>
         </property>
         <layout class="QGridLayout">
          <item row="0" column="0">
@@ -94,7 +94,7 @@
             </size>
            </property>
            <property name="text">
-            <string>Preferred subtitles language</string>
+            <string>Preferred subtitle language</string>
            </property>
            <property name="buddy">
             <cstring>preferredLanguage</cstring>
@@ -133,7 +133,7 @@
       <item>
        <widget class="QGroupBox" name="groupBox">
         <property name="title">
-         <string>Subtitles effects</string>
+         <string>Subtitle effects</string>
         </property>
         <layout class="QGridLayout" name="gridLayout_2">
          <item row="0" column="0">
diff --git a/modules/stream_out/transcode/spu.c b/modules/stream_out/transcode/spu.c
index d008d2d..b33d006 100644
--- a/modules/stream_out/transcode/spu.c
+++ b/modules/stream_out/transcode/spu.c
@@ -164,7 +164,7 @@ bool transcode_spu_add( sout_stream_t *p_stream, es_format_t *p_fmt,
 
     if( p_sys->i_scodec || p_sys->psz_senc )
     {
-        msg_Dbg( p_stream, "creating subtitles transcoding from fcc=`%4.4s' "
+        msg_Dbg( p_stream, "creating subtitle transcoding from fcc=`%4.4s' "
                  "to fcc=`%4.4s'", (char*)&p_fmt->i_codec,
                  (char*)&p_sys->i_scodec );
 
@@ -174,7 +174,7 @@ bool transcode_spu_add( sout_stream_t *p_stream, es_format_t *p_fmt,
         /* build decoder -> filter -> encoder */
         if( transcode_spu_new( p_stream, id ) )
         {
-            msg_Err( p_stream, "cannot create subtitles chain" );
+            msg_Err( p_stream, "cannot create subtitle chain" );
             return false;
         }
 
@@ -191,7 +191,7 @@ bool transcode_spu_add( sout_stream_t *p_stream, es_format_t *p_fmt,
     else
     {
         assert( p_sys->b_soverlay );
-        msg_Dbg( p_stream, "subtitles (fcc=`%4.4s') overlaying",
+        msg_Dbg( p_stream, "subtitle (fcc=`%4.4s') overlaying",
                  (char*)&p_fmt->i_codec );
 
         id->b_transcode = true;
@@ -199,7 +199,7 @@ bool transcode_spu_add( sout_stream_t *p_stream, es_format_t *p_fmt,
         /* Build decoder -> filter -> overlaying chain */
         if( transcode_spu_new( p_stream, id ) )
         {
-            msg_Err( p_stream, "cannot create subtitles chain" );
+            msg_Err( p_stream, "cannot create subtitle chain" );
             return false;
         }
     }
diff --git a/modules/stream_out/transcode/transcode.c b/modules/stream_out/transcode/transcode.c
index 3ff29ad..8998020 100644
--- a/modules/stream_out/transcode/transcode.c
+++ b/modules/stream_out/transcode/transcode.c
@@ -104,13 +104,13 @@
     "Audio filters will be applied to the audio streams (after conversion " \
     "filters are applied). You can enter a colon-separated list of filters." )
 
-#define SENC_TEXT N_("Subtitles encoder")
+#define SENC_TEXT N_("Subtitle encoder")
 #define SENC_LONGTEXT N_( \
-    "This is the subtitles encoder module that will be used (and its " \
+    "This is the subtitle encoder module that will be used (and its " \
     "associated options)." )
-#define SCODEC_TEXT N_("Destination subtitles codec")
+#define SCODEC_TEXT N_("Destination subtitle codec")
 #define SCODEC_LONGTEXT N_( \
-    "This is the subtitles codec that will be used." )
+    "This is the subtitle codec that will be used." )
 
 #define SFILTER_TEXT N_("Overlays")
 #define SFILTER_LONGTEXT N_( \
diff --git a/modules/video_filter/subsdelay.c b/modules/video_filter/subsdelay.c
index 6395db2..be727cf 100644
--- a/modules/video_filter/subsdelay.c
+++ b/modules/video_filter/subsdelay.c
@@ -42,7 +42,7 @@
 
 /* descriptions */
 
-#define SUBSDELAY_HELP N_("Change subtitles delay")
+#define SUBSDELAY_HELP N_("Change subtitle delay")
 
 #define MODE_TEXT N_( "Delay calculation mode" )
 #define MODE_LONGTEXT N_( \
@@ -272,7 +272,7 @@ static void SubsdelayEntryNewStopValueUpdated( subsdelay_heap_entry_t *p_entry )
 
 vlc_module_begin()
         set_shortname( _("Subsdelay") )
-        set_description( _("Subtitles delay") )
+        set_description( _("Subtitle delay") )
         set_help( SUBSDELAY_HELP )
         set_capability( "sub filter", 0 )
         set_callbacks( SubsdelayCreate, SubsdelayDestroy )
diff --git a/modules/video_output/msw/direct3d.c b/modules/video_output/msw/direct3d.c
index 0f406c1..adf2b33 100644
--- a/modules/video_output/msw/direct3d.c
+++ b/modules/video_output/msw/direct3d.c
@@ -58,7 +58,7 @@ static void Close(vlc_object_t *);
 
 #define HW_BLENDING_TEXT N_("Use hardware blending support")
 #define HW_BLENDING_LONGTEXT N_(\
-    "Try to use hardware acceleration for subtitles/OSD blending.")
+    "Try to use hardware acceleration for subtitle/OSD blending.")
 
 #define D3D_HELP N_("Recommended video output for Windows Vista and later versions")
 
diff --git a/share/lua/http/dialogs/old/input b/share/lua/http/dialogs/old/input
index 6f23672..ba3ea91 100644
--- a/share/lua/http/dialogs/old/input
+++ b/share/lua/http/dialogs/old/input
@@ -80,10 +80,10 @@ This dialog needs the following dialogs to be fully functional: browse
       <input type="checkbox" id="input_sub_options" />
       <label for="input_sub_options">Subtitle options *TODO/FIXME/FIXHTTPD*</label>
       <br/>
-      <label for="input_sub_file">Subtitles file</label>
+      <label for="input_sub_file">Subtitle file</label>
       <input type="text" id="input_sub_file" size="60" />
       <br/>
-      <label for="input_sub_enc">Subtitles encoding</label>
+      <label for="input_sub_enc">Subtitle encoding</label>
       <select id="input_sub_enc">
         <option></option>
       </select>
@@ -142,7 +142,7 @@ This dialog needs the following dialogs to be fully functional: browse
         </tr>
         <tr>
           <td>
-            <label for="input_disc_subtrack">Subtitles track</label>
+            <label for="input_disc_subtrack">Subtitle track</label>
           </td>
           <td>
              <input type="text" id="input_disc_subtrack" onchange="update_input_disc();" />
diff --git a/share/lua/http/dialogs/old/sout b/share/lua/http/dialogs/old/sout
index 419e500..a70617c 100644
--- a/share/lua/http/dialogs/old/sout
+++ b/share/lua/http/dialogs/old/sout
@@ -260,7 +260,7 @@ Note that the sout chain is used and sent to VLC by the input dialog
         <tr>
           <td>
             <input type="checkbox" id="sout_sub" onchange="update_sout()"/>
-            <label for="sout_sub">Subtitles Codec</label>
+            <label for="sout_sub">Subtitle Codec</label>
           </td>
           <td>
             <select id="sout_scodec" onchange="update_sout()">
@@ -269,7 +269,7 @@ Note that the sout chain is used and sent to VLC by the input dialog
           </td>
           <td colspan="2">
             <input type="checkbox" id="sout_soverlay" onchange="update_sout()"/>
-            <label for="sout_soverlay">Subtitles overlay</label>
+            <label for="sout_soverlay">Subtitle overlay</label>
           </td>
         </tr>
       </table>
diff --git a/share/lua/intf/cli.lua b/share/lua/intf/cli.lua
index 558952d..ffe3fed 100644
--- a/share/lua/intf/cli.lua
+++ b/share/lua/intf/cli.lua
@@ -573,7 +573,7 @@ commands_ordered = {
     { "vdeinterlace"; { func = skip(listvalue("vout","deinterlace")); args = "[X]"; help = "set/get video deinterlace" } };
     { "vdeinterlace_mode"; { func = skip(listvalue("vout","deinterlace-mode")); args = "[X]"; help = "set/get video deinterlace mode" } };
     { "snapshot"; { func = common.snapshot; help = "take video snapshot" } };
-    { "strack"; { func = skip(listvalue("input","spu-es")); args = "[X]"; help = "set/get subtitles track" } };
+    { "strack"; { func = skip(listvalue("input","spu-es")); args = "[X]"; help = "set/get subtitle track" } };
     { "hotkey"; { func = hotkey; args = "[hotkey name]"; help = "simulate hotkey press"; adv = true; aliases = { "key" } } };
     { "" };
     { "vlm"; { func = load_vlm; help = "load the VLM" } };
diff --git a/src/input/var.c b/src/input/var.c
index 9613fe2..3e3d112 100644
--- a/src/input/var.c
+++ b/src/input/var.c
@@ -207,7 +207,7 @@ void input_ControlVarInit ( input_thread_t *p_input )
 
     /* Spu ES */
     var_Create( p_input, "spu-es", VLC_VAR_INTEGER | VLC_VAR_HASCHOICE );
-    text.psz_string = _("Subtitles Track");
+    text.psz_string = _("Subtitle Track");
     var_Change( p_input, "spu-es", VLC_VAR_SETTEXT, &text, NULL );
 
     /* Special read only objects variables for intf */
diff --git a/src/libvlc-module.c b/src/libvlc-module.c
index 86cee40..e97bd1c 100644
--- a/src/libvlc-module.c
+++ b/src/libvlc-module.c
@@ -586,7 +586,7 @@ static const char *const ppsz_clock_descriptions[] =
     "Stream number of the audio track to use " \
     "(from 0 to n).")
 
-#define INPUT_SUBTRACK_TEXT N_("Subtitles track")
+#define INPUT_SUBTRACK_TEXT N_("Subtitle track")
 #define INPUT_SUBTRACK_LONGTEXT N_( \
     "Stream number of the subtitle track to use " \
     "(from 0 to n).")
@@ -606,7 +606,7 @@ static const char *const ppsz_clock_descriptions[] =
 #define INPUT_AUDIOTRACK_ID_LONGTEXT N_( \
     "Stream ID of the audio track to use.")
 
-#define INPUT_SUBTRACK_ID_TEXT N_("Subtitles track ID")
+#define INPUT_SUBTRACK_ID_TEXT N_("Subtitle track ID")
 #define INPUT_SUBTRACK_ID_LONGTEXT N_( \
     "Stream ID of the subtitle track to use.")
 
@@ -723,7 +723,7 @@ static const char *const ppsz_prefres[] = {
 #define SUB_FILTER_TEXT N_("Subpictures filter module")
 #define SUB_FILTER_LONGTEXT N_( \
     "This adds so-called \"subpicture filters\". These filter subpictures " \
-    "created by subtitles decoders or other subpictures sources." )
+    "created by subtitle decoders or other subpictures sources." )
 
 #define SUB_AUTO_TEXT N_("Autodetect subtitle files")
 #define SUB_AUTO_LONGTEXT N_( \
diff --git a/modules/codec/subsdec.c b/modules/codec/subsdec.c
index 357fbf9..9eff500 100644
--- a/modules/codec/subsdec.c
+++ b/modules/codec/subsdec.c
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * subsdec.c : text subtitles decoder
  *****************************************************************************
  * Copyright (C) 2000-2006 VLC authors and VideoLAN
  * $Id$
@@ -163,13 +163,13 @@ static const int  pi_justification[] = { 0, 1, 2 };
 static const char *const ppsz_justification_text[] = {
     N_("Center"),N_("Left"),N_("Right")};
 
-#define ENCODING_TEXT N_("Subtitles text encoding")
+#define ENCODING_TEXT N_("Subtitle text encoding")
 #define ENCODING_LONGTEXT N_("Set the encoding used in text subtitles")
-#define ALIGN_TEXT N_("Subtitles justification")
+#define ALIGN_TEXT N_("Subtitle justification")
 #define ALIGN_LONGTEXT N_("Set the justification of subtitles")
-#define AUTODETECT_UTF8_TEXT N_("UTF-8 subtitles autodetection")
+#define AUTODETECT_UTF8_TEXT N_("UTF-8 subtitle autodetection")
 #define AUTODETECT_UTF8_LONGTEXT N_("This enables automatic detection of " \
-            "UTF-8 encoding within subtitles files.")
+            "UTF-8 encoding within subtitle files.")
 #define FORMAT_TEXT N_("Formatted Subtitles")
 #define FORMAT_LONGTEXT N_("Some subtitle formats allow for text formatting. " \
  "VLC partly implements this, but you can choose to disable all formatting.")
@@ -179,7 +179,7 @@ static void CloseDecoder  ( vlc_object_t * );
 
 vlc_module_begin ()
     set_shortname( N_("Subtitles"))
-    set_description( N_("Text subtitles decoder") )
+    set_description( N_("Text subtitle decoder") )
     set_capability( "decoder", 50 )
     set_callbacks( OpenDecoder, CloseDecoder )
     set_category( CAT_INPUT )
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * subsdec.c : text subtitles decoder
+ * subsdec.c : text subtitle decoder
  *****************************************************************************
  * Copyright (C) 2000-2006 VLC authors and VideoLAN
diff --git a/src/input/input.c b/src/input/input.c
index 729b666..073de23 100644
--- a/src/input/input.c
+++ b/src/input/input.c
@@ -3171,7 +3171,7 @@ static void MRLSections( const char *p,
 }
 
 /*****************************************************************************
  * input_AddSubtitles: add a subtitles file and enable it
  *****************************************************************************/
 static void SubtitleAdd( input_thread_t *p_input, char *psz_subtitle, unsigned i_flags )
 {
@@ -3194,7 +3194,7 @@ static void SubtitleAdd( input_thread_t *p_input, char *psz_subtitle, unsigned i
 
             if( !vlc_stat( psz_path, &st ) && S_ISREG( st.st_mode ) )
             {
-                msg_Dbg( p_input, "using %s subtitles file instead of %s",
+                msg_Dbg( p_input, "using %s as subtitle file instead of %s",
                          psz_path, psz_subtitle );
                 strcpy( psz_subtitle, psz_path );
             }
@@ -3171,7 +3171,7 @@ static void MRLSections( const char *p,
 
 /*****************************************************************************
- * input_AddSubtitles: add a subtitles file and enable it
+ * input_AddSubtitles: add a subtitle file and enable it
  *****************************************************************************/
 static void SubtitleAdd( input_thread_t *p_input, char *psz_subtitle, unsigned i_flags )
-- 
1.7.5.4




More information about the vlc-devel mailing list